@@ -38,22 +38,53 @@ pub enum PrincipalOrId {
 impl Server {
     async fn build_access_token_from_principal(
         &self,
-        mut principal: Principal,
+        principal: Principal,
         revision: u64,
     ) -> trc::Result<AccessToken> {
         let mut role_permissions = RolePermissions::default();
 
-        // Apply role permissions
-        for role_id in principal.roles() {
-            role_permissions.union(self.get_role_permissions(*role_id).await?.as_ref());
-        }
-
-        // Add principal permissions
-        for permission in principal.permissions() {
-            if permission.grant {
-                role_permissions.enabled.set(permission.permission.id());
-            } else {
-                role_permissions.disabled.set(permission.permission.id());
+        // Extract data
+        let mut object_quota = self.core.jmap.max_objects;
+        let mut description = None;
+        let mut tenant_id = None;
+        let mut quota = None;
+        let mut locale = None;
+        let mut member_of = Vec::new();
+        let mut emails = Vec::new();
+        for data in principal.data {
+            match data {
+                PrincipalData::Tenant(v) => tenant_id = Some(v),
+                PrincipalData::MemberOf(v) => member_of.push(v),
+                PrincipalData::Role(v) => {
+                    role_permissions.union(self.get_role_permissions(v).await?.as_ref());
+                }
+                PrincipalData::Permission {
+                    permission_id,
+                    grant,
+                } => {
+                    if grant {
+                        role_permissions.enabled.set(permission_id as usize);
+                    } else {
+                        role_permissions.disabled.set(permission_id as usize);
+                    }
+                }
+                PrincipalData::DiskQuota(v) => quota = Some(v),
+                PrincipalData::ObjectQuota { quota, typ } => {
+                    object_quota[typ as usize] = quota;
+                }
+                PrincipalData::Description(v) => description = Some(v),
+                PrincipalData::PrimaryEmail(v) => {
+                    if emails.is_empty() {
+                        emails.push(v);
+                    } else {
+                        emails.insert(0, v);
+                    }
+                }
+                PrincipalData::EmailAlias(v) => {
+                    emails.push(v);
+                }
+                PrincipalData::Locale(v) => locale = Some(v),
+                _ => (),
             }
         }
 
@@ -67,7 +98,7 @@ impl Server {
 
         #[cfg(feature = "enterprise")]
         if self.is_enterprise_edition()
-            && let Some(tenant_id) = principal.tenant
+            && let Some(tenant_id) = tenant_id
         {
             // Limit tenant permissions
 
@@ -89,7 +120,7 @@ impl Server {
                             .id(tenant_id)
                             .caused_by(trc::location!())
                     })?
-                    .quota
+                    .quota()
                     .unwrap_or_default(),
             });
         }
@@ -97,12 +128,6 @@ impl Server {
         // SPDX-SnippetEnd
 
         // Build member of and e-mail addresses
-        let primary_id = principal.id();
-        let member_of = principal
-            .member_of_mut()
-            .map(std::mem::take)
-            .unwrap_or_default();
-        let mut emails = principal.emails;
         for &group_id in &member_of {
             if let Some(group) = self
                 .store()
@@ -111,28 +136,23 @@ impl Server {
                 .caused_by(trc::location!())?
                 && group.typ == Type::Group
             {
-                emails.extend(group.emails);
+                emails.extend(group.into_email_addresses());
             }
         }
 
         // Build access token
         let mut access_token = AccessToken {
-            primary_id,
+            primary_id: principal.id,
             member_of,
             access_to: VecMap::new(),
             tenant,
             name: principal.name,
-            description: principal.description,
+            description,
             emails,
-            quota: principal.quota.unwrap_or_default(),
-            locale: principal.data.iter().find_map(|data| {
-                if let PrincipalData::Locale(v) = data {
-                    Some(v.to_string())
-                } else {
-                    None
-                }
-            }),
+            quota: quota.unwrap_or_default(),
+            locale,
             permissions,
+            object_quota,
             concurrent_imap_requests: self.core.imap.rate_concurrent.map(ConcurrencyLimiter::new),
             concurrent_http_requests: self
                 .core
@@ -170,13 +190,13 @@ impl Server {
                     }
 
                     let mut collections: Bitmap<Collection> = Bitmap::new();
-                    if acl.contains(Acl::Read) || acl.contains(Acl::Administer) {
+                    if acl.contains(Acl::Read) {
                         collections.insert(collection);
                     }
-                    if collection == Collection::Mailbox
-                        && (acl.contains(Acl::ReadItems) || acl.contains(Acl::Administer))
+                    if acl.contains(Acl::ReadItems)
+                        && let Some(child_col) = collection.child_collection()
                     {
-                        collections.insert(Collection::Email);
+                        collections.insert(child_col);
                     }
 
                     if !collections.is_empty() {
@@ -350,7 +370,7 @@ impl Server {
 
         // Invalidate DAV caches
         if !changed_names.is_empty() {
-            self.cluster_broadcast(BroadcastEvent::InvalidateDavCache(changed_names))
+            self.cluster_broadcast(BroadcastEvent::InvalidateGroupwareCache(changed_names))
                 .await;
         }
     }
@@ -390,7 +410,7 @@ impl AccessToken {
     }
 
     pub fn with_permission(mut self, permission: Permission) -> Self {
-        self.permissions.set(permission.id());
+        self.permissions.set(permission.id() as usize);
         self
     }
 
@@ -402,16 +422,28 @@ impl AccessToken {
         s.finish() as u32
     }
 
+    #[inline(always)]
     pub fn primary_id(&self) -> u32 {
         self.primary_id
     }
 
+    #[inline(always)]
+    pub fn tenant_id(&self) -> Option<u32> {
+        self.tenant.as_ref().map(|t| t.id)
+    }
+
     pub fn secondary_ids(&self) -> impl Iterator<Item = &u32> {
         self.member_of
             .iter()
             .chain(self.access_to.iter().map(|(id, _)| id))
     }
 
+    pub fn member_ids(&self) -> impl Iterator<Item = u32> {
+        [self.primary_id]
+            .into_iter()
+            .chain(self.member_of.iter().copied())
+    }
+
     pub fn all_ids(&self) -> impl Iterator<Item = u32> {
         [self.primary_id]
             .into_iter()
@@ -444,7 +476,7 @@ impl AccessToken {
 
     #[inline(always)]
     pub fn has_permission(&self, permission: Permission) -> bool {
-        self.permissions.get(permission.id())
+        self.permissions.get(permission.id() as usize)
     }
 
     pub fn assert_has_permission(&self, permission: Permission) -> trc::Result<bool> {
@@ -469,7 +501,7 @@ impl AccessToken {
                 let item = USIZE_MASK - bytes.leading_zeros();
                 bytes ^= 1 << item;
                 if let Some(permission) =
-                    Permission::from_id((block_num * USIZE_BITS) + item as usize)
+                    Permission::from_id(((block_num * USIZE_BITS) + item as usize) as u32)
                 {
                     permissions.push(permission);
                 }
@@ -478,6 +510,11 @@ impl AccessToken {
         permissions
     }
 
+    #[inline(always)]
+    pub fn object_quota(&self, collection: Collection) -> u32 {
+        self.object_quota[collection as usize]
+    }
+
     pub fn is_shared(&self, account_id: u32) -> bool {
         !self.is_member(account_id) && self.access_to.iter().any(|(id, _)| *id == account_id)
     }
@@ -538,6 +575,7 @@ impl AccessToken {
             + (self.access_to.len() * (std::mem::size_of::<u32>() + std::mem::size_of::<u64>()))
             + self.name.len()
             + self.description.as_ref().map_or(0, |v| v.len())
+            + self.locale.as_ref().map_or(0, |v| v.len())
             + self.emails.iter().map(|v| v.len()).sum::<usize>()) as u64;
         self
     }
