@@ -14,7 +14,7 @@ use crate::{
             QueueStrategy, RequireOptional, RoutingStrategy, TlsStrategy, VirtualQueue,
         },
     },
-    ipc::{BroadcastEvent, StateEvent},
+    ipc::{BroadcastEvent, PushEvent, PushNotification},
 };
 use directory::{Directory, QueryParams, Type, backend::internal::manage::ManageDirectory};
 use mail_auth::IpLookupStrategy;
@@ -41,6 +41,7 @@ use types::{
     field::{EmailField, Field},
     type_state::{DataType, StateChange},
 };
+use utils::{map::bitmap::Bitmap, snowflake::SnowflakeIdGenerator};
 
 impl Server {
     #[inline(always)]
@@ -454,7 +455,7 @@ impl Server {
                 .await
                 .add_context(|err| err.caused_by(trc::location!()).account_id(account_id))?
             {
-                quotas.quota = principal.quota();
+                quotas.quota = principal.quota().unwrap_or_default();
 
                 // SPDX-SnippetBegin
                 // SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
@@ -475,7 +476,7 @@ impl Server {
                             .add_context(|err| {
                                 err.caused_by(trc::location!()).account_id(tenant_id)
                             })?
-                            .map(|tenant| tenant.quota())
+                            .and_then(|tenant| tenant.quota())
                             .unwrap_or_default(),
                     }
                     .into();
@@ -649,8 +650,7 @@ impl Server {
 
         if let Some(changes) = builder.changes() {
             for (account_id, changed_collections) in changes {
-                let mut state_change =
-                    StateChange::new(account_id, assigned_ids.last_change_id(account_id)?);
+                let mut state_change = StateChange::new(account_id);
                 for changed_collection in changed_collections.changed_containers {
                     if let Some(data_type) = DataType::try_from_sync(changed_collection, true) {
                         state_change.set_change(data_type);
@@ -662,7 +662,18 @@ impl Server {
                     }
                 }
                 if state_change.has_changes() {
-                    self.broadcast_state_change(state_change).await;
+                    self.broadcast_push_notification(PushNotification::StateChange(
+                        state_change.with_change_id(assigned_ids.last_change_id(account_id)?),
+                    ))
+                    .await;
+                }
+                if let Some(change_id) = changed_collections.share_notification_id {
+                    self.broadcast_push_notification(PushNotification::StateChange(StateChange {
+                        account_id,
+                        change_id,
+                        types: Bitmap::from_iter([DataType::ShareNotification]),
+                    }))
+                    .await;
                 }
             }
         }
@@ -670,117 +681,142 @@ impl Server {
         Ok(assigned_ids)
     }
 
-    pub async fn delete_changes(&self, account_id: u32, max_entries: usize) -> trc::Result<()> {
-        for sync_collection in [
-            SyncCollection::Email,
-            SyncCollection::Thread,
-            SyncCollection::Identity,
-            SyncCollection::EmailSubmission,
-            SyncCollection::SieveScript,
-            SyncCollection::FileNode,
-            SyncCollection::AddressBook,
-            SyncCollection::Calendar,
-        ] {
-            let collection = sync_collection.into();
-            let from_key = LogKey {
-                account_id,
-                collection,
-                change_id: 0,
-            };
-            let to_key = LogKey {
-                account_id,
-                collection,
-                change_id: u64::MAX,
-            };
+    pub async fn delete_changes(
+        &self,
+        account_id: u32,
+        max_entries: Option<usize>,
+        max_duration: Option<Duration>,
+    ) -> trc::Result<()> {
+        if let Some(max_entries) = max_entries {
+            for sync_collection in [
+                SyncCollection::Email,
+                SyncCollection::Thread,
+                SyncCollection::Identity,
+                SyncCollection::EmailSubmission,
+                SyncCollection::SieveScript,
+                SyncCollection::FileNode,
+                SyncCollection::AddressBook,
+                SyncCollection::Calendar,
+            ] {
+                let collection = sync_collection.into();
+                let from_key = LogKey {
+                    account_id,
+                    collection,
+                    change_id: 0,
+                };
+                let to_key = LogKey {
+                    account_id,
+                    collection,
+                    change_id: u64::MAX,
+                };
 
-            let mut first_change_id = 0;
-            let mut num_changes = 0;
+                let mut first_change_id = 0;
+                let mut num_changes = 0;
 
-            self.store()
-                .iterate(
-                    IterateParams::new(from_key, to_key)
-                        .descending()
-                        .no_values(),
-                    |key, _| {
-                        first_change_id = key.deserialize_be_u64(key.len() - U64_LEN)?;
-                        num_changes += 1;
-
-                        Ok(num_changes <= max_entries)
-                    },
-                )
-                .await
-                .caused_by(trc::location!())?;
-
-            if num_changes > max_entries {
                 self.store()
-                    .delete_range(
-                        LogKey {
-                            account_id,
-                            collection,
-                            change_id: 0,
-                        },
-                        LogKey {
-                            account_id,
-                            collection,
-                            change_id: first_change_id,
+                    .iterate(
+                        IterateParams::new(from_key, to_key)
+                            .descending()
+                            .no_values(),
+                        |key, _| {
+                            first_change_id = key.deserialize_be_u64(key.len() - U64_LEN)?;
+                            num_changes += 1;
+
+                            Ok(num_changes <= max_entries)
                         },
                     )
                     .await
                     .caused_by(trc::location!())?;
 
-                // Delete vanished items
-                if let Some(vanished_collection) =
-                    sync_collection.vanished_collection().map(u8::from)
-                {
+                if num_changes > max_entries {
                     self.store()
                         .delete_range(
                             LogKey {
                                 account_id,
-                                collection: vanished_collection,
+                                collection,
                                 change_id: 0,
                             },
                             LogKey {
                                 account_id,
-                                collection: vanished_collection,
+                                collection,
                                 change_id: first_change_id,
                             },
                         )
                         .await
                         .caused_by(trc::location!())?;
-                }
 
-                // Write truncation entry for cache
-                let mut batch = BatchBuilder::new();
-                batch.with_account_id(account_id).set(
-                    ValueClass::Any(AnyClass {
-                        subspace: SUBSPACE_LOGS,
-                        key: LogKey {
-                            account_id,
-                            collection,
-                            change_id: first_change_id,
-                        }
-                        .serialize(0),
-                    }),
-                    Vec::new(),
-                );
-                self.store()
-                    .write(batch.build_all())
-                    .await
-                    .caused_by(trc::location!())?;
+                    // Delete vanished items
+                    if let Some(vanished_collection) =
+                        sync_collection.vanished_collection().map(u8::from)
+                    {
+                        self.store()
+                            .delete_range(
+                                LogKey {
+                                    account_id,
+                                    collection: vanished_collection,
+                                    change_id: 0,
+                                },
+                                LogKey {
+                                    account_id,
+                                    collection: vanished_collection,
+                                    change_id: first_change_id,
+                                },
+                            )
+                            .await
+                            .caused_by(trc::location!())?;
+                    }
+
+                    // Write truncation entry for cache
+                    let mut batch = BatchBuilder::new();
+                    batch.with_account_id(account_id).set(
+                        ValueClass::Any(AnyClass {
+                            subspace: SUBSPACE_LOGS,
+                            key: LogKey {
+                                account_id,
+                                collection,
+                                change_id: first_change_id,
+                            }
+                            .serialize(0),
+                        }),
+                        Vec::new(),
+                    );
+                    self.store()
+                        .write(batch.build_all())
+                        .await
+                        .caused_by(trc::location!())?;
+                }
             }
         }
 
+        if let Some(max_duration) = max_duration {
+            self.store()
+                .delete_range(
+                    LogKey {
+                        account_id,
+                        collection: SyncCollection::ShareNotification.into(),
+                        change_id: 0,
+                    },
+                    LogKey {
+                        account_id,
+                        collection: SyncCollection::ShareNotification.into(),
+                        change_id: SnowflakeIdGenerator::from_duration(max_duration)
+                            .unwrap_or_default(),
+                    },
+                )
+                .await
+                .caused_by(trc::location!())?;
+        }
         Ok(())
     }
 
-    pub async fn broadcast_state_change(&self, state_change: StateChange) -> bool {
+    pub async fn broadcast_push_notification(&self, notification: PushNotification) -> bool {
         match self
             .inner
             .ipc
-            .state_tx
+            .push_tx
             .clone()
-            .send(StateEvent::Publish {
-                state_change,
+            .send(PushEvent::Publish {
+                notification,
                 broadcast: true,
             })
             .await
