@@ -36,6 +36,31 @@ impl DavResources {
         document_ids
     }
 
+    pub fn shared_items(
+        &self,
+        access_token: &AccessToken,
+        check_acls: impl IntoIterator<Item = Acl>,
+        match_any: bool,
+    ) -> RoaringBitmap {
+        let shared_containers = self.shared_containers(access_token, check_acls, match_any);
+
+        if !shared_containers.is_empty() {
+            let mut document_ids = RoaringBitmap::new();
+
+            for path in &self.paths {
+                if let Some(parent_id) = path.parent_id
+                    && shared_containers.contains(parent_id)
+                {
+                    document_ids.insert(self.resources[path.resource_idx].document_id);
+                }
+            }
+
+            document_ids
+        } else {
+            shared_containers
+        }
+    }
+
     pub fn has_access_to_container(
         &self,
         access_token: &AccessToken,
@@ -80,4 +105,26 @@ impl DavResources {
 
         account_acls
     }
+
+    pub fn document_ids(&self, is_container: bool) -> impl Iterator<Item = u32> {
+        self.resources.iter().filter_map(move |resource| {
+            if resource.is_container() == is_container {
+                Some(resource.document_id)
+            } else {
+                None
+            }
+        })
+    }
+
+    pub fn has_container_id(&self, id: &u32) -> bool {
+        self.resources
+            .iter()
+            .any(|r| r.document_id == *id && r.is_container())
+    }
+
+    pub fn has_item_id(&self, id: &u32) -> bool {
+        self.resources
+            .iter()
+            .any(|r| r.document_id == *id && !r.is_container())
+    }
 }
