@@ -4,6 +4,14 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use crate::{
+    DavError, DavMethod,
+    common::{
+        ETag,
+        lock::{LockRequestHandler, ResourceState},
+        uri::DavUriResource,
+    },
+};
 use common::{Server, auth::AccessToken, sharing::EffectiveAcl};
 use dav_proto::RequestHeaders;
 use groupware::{
@@ -13,20 +21,11 @@ use groupware::{
 };
 use http_proto::HttpResponse;
 use hyper::StatusCode;
-use jmap_proto::types::{
-    acl::Acl,
-    collection::{Collection, SyncCollection},
-};
 use store::write::BatchBuilder;
 use trc::AddContext;
-
-use crate::{
-    DavError, DavMethod,
-    common::{
-        ETag,
-        lock::{LockRequestHandler, ResourceState},
-        uri::DavUriResource,
-    },
+use types::{
+    acl::Acl,
+    collection::{Collection, SyncCollection},
 };
 
 pub(crate) trait CardDeleteRequestHandler: Sync + Send {
