@@ -10,7 +10,7 @@ use crate::{DavError, DavErrorCondition, DavMethod};
 use common::KV_LOCK_DAV;
 use common::{Server, auth::AccessToken};
 use dav_proto::schema::property::{ActiveLock, LockScope, WebDavProperty};
-use dav_proto::schema::request::{DavPropertyValue, DeadProperty};
+use dav_proto::schema::request::DavPropertyValue;
 use dav_proto::schema::response::{BaseCondition, List, PropResponse};
 use dav_proto::{Condition, Depth, Timeout};
 use dav_proto::{RequestHeaders, schema::request::LockInfo};
@@ -24,6 +24,7 @@ use store::write::{AlignedBytes, Archive, Archiver, now};
 use store::{Serialize, U32_LEN};
 use trc::AddContext;
 use types::collection::Collection;
+use types::dead_property::DeadProperty;
 
 #[derive(Debug, Default, Clone)]
 pub struct ResourceState<'x> {
