@@ -8,21 +8,22 @@ use calcard::{
     icalendar::{ICalendarComponentType, ICalendarParameterName, ICalendarProperty},
     vcard::{VCardParameterName, VCardVersion},
 };
+use common::auth::AccessToken;
 use dav_proto::{
     Depth, RequestHeaders, Return,
     schema::{
         Namespace,
-        property::{DavProperty, ReportSet, ResourceType, TimeRange},
+        property::{DavProperty, ReportSet, ResourceType},
         request::{
-            AddressbookQuery, ArchivedDeadProperty, CalendarQuery, ExpandProperty, Filter,
-            MultiGet, PropFind, SyncCollection, Timezone, VCardPropertyWithGroup,
+            AddressbookQuery, CalendarQuery, ExpandProperty, Filter, MultiGet, PropFind,
+            SyncCollection, Timezone, VCardPropertyWithGroup,
         },
     },
 };
 use groupware::{
     calendar::{
-        ArchivedCalendar, ArchivedCalendarEvent, ArchivedCalendarScheduling, Calendar,
-        CalendarEvent, CalendarScheduling,
+        ArchivedCalendar, ArchivedCalendarEvent, ArchivedCalendarEventNotification, Calendar,
+        CalendarEvent, CalendarEventNotification,
     },
     contact::{AddressBook, ArchivedAddressBook, ArchivedContactCard, ContactCard},
     file::{ArchivedFileNode, FileNode},
@@ -30,7 +31,10 @@ use groupware::{
 use propfind::PropFindItem;
 use rkyv::vec::ArchivedVec;
 use store::write::{AlignedBytes, Archive, BatchBuilder, Operation, ValueClass, ValueOp};
-use types::{acl::ArchivedAclGrant, collection::Collection, field::Field};
+use types::{
+    TimeRange, acl::ArchivedAclGrant, collection::Collection, dead_property::ArchivedDeadProperty,
+    field::Field,
+};
 use uri::{OwnedUri, Urn};
 
 pub mod acl;
@@ -134,9 +138,9 @@ pub(crate) trait DavCollection {
 impl DavCollection for Collection {
     fn namespace(&self) -> Namespace {
         match self {
-            Collection::Calendar | Collection::CalendarEvent | Collection::CalendarScheduling => {
-                Namespace::CalDav
-            }
+            Collection::Calendar
+            | Collection::CalendarEvent
+            | Collection::CalendarEventNotification => Namespace::CalDav,
             Collection::AddressBook | Collection::ContactCard => Namespace::CardDav,
             _ => Namespace::Dav,
         }
@@ -307,8 +311,8 @@ impl<'x> DavQuery<'x> {
 pub(crate) enum ArchivedResource<'x> {
     Calendar(Archive<&'x ArchivedCalendar>),
     CalendarEvent(Archive<&'x ArchivedCalendarEvent>),
-    CalendarScheduling(Archive<&'x ArchivedCalendarScheduling>),
-    CalendarSchedulingCollection(bool),
+    CalendarEventNotification(Archive<&'x ArchivedCalendarEventNotification>),
+    CalendarEventNotificationCollection(bool),
     AddressBook(Archive<&'x ArchivedAddressBook>),
     ContactCard(Archive<&'x ArchivedContactCard>),
     FileNode(Archive<&'x ArchivedFileNode>),
@@ -326,9 +330,9 @@ impl<'x> ArchivedResource<'x> {
             Collection::CalendarEvent => archive
                 .to_unarchived::<CalendarEvent>()
                 .map(ArchivedResource::CalendarEvent),
-            Collection::CalendarScheduling => archive
-                .to_unarchived::<CalendarScheduling>()
-                .map(ArchivedResource::CalendarScheduling),
+            Collection::CalendarEventNotification => archive
+                .to_unarchived::<CalendarEventNotification>()
+                .map(ArchivedResource::CalendarEventNotification),
             Collection::AddressBook => archive
                 .to_unarchived::<AddressBook>()
                 .map(ArchivedResource::AddressBook),
@@ -358,8 +362,10 @@ impl<'x> ArchivedResource<'x> {
             ArchivedResource::AddressBook(archive) => archive.inner.created.to_native(),
             ArchivedResource::ContactCard(archive) => archive.inner.created.to_native(),
             ArchivedResource::FileNode(archive) => archive.inner.created.to_native(),
-            ArchivedResource::CalendarScheduling(archive) => archive.inner.created.to_native(),
-            ArchivedResource::CalendarSchedulingCollection(_) => 1634515200,
+            ArchivedResource::CalendarEventNotification(archive) => {
+                archive.inner.created.to_native()
+            }
+            ArchivedResource::CalendarEventNotificationCollection(_) => 1634515200,
         }
     }
 
@@ -370,8 +376,10 @@ impl<'x> ArchivedResource<'x> {
             ArchivedResource::AddressBook(archive) => archive.inner.modified.to_native(),
             ArchivedResource::ContactCard(archive) => archive.inner.modified.to_native(),
             ArchivedResource::FileNode(archive) => archive.inner.modified.to_native(),
-            ArchivedResource::CalendarScheduling(archive) => archive.inner.modified.to_native(),
-            ArchivedResource::CalendarSchedulingCollection(_) => 1634515200,
+            ArchivedResource::CalendarEventNotification(archive) => {
+                archive.inner.modified.to_native()
+            }
+            ArchivedResource::CalendarEventNotificationCollection(_) => 1634515200,
         }
     }
 
@@ -382,8 +390,8 @@ impl<'x> ArchivedResource<'x> {
             ArchivedResource::AddressBook(archive) => Some(&archive.inner.dead_properties),
             ArchivedResource::ContactCard(archive) => Some(&archive.inner.dead_properties),
             ArchivedResource::FileNode(archive) => Some(&archive.inner.dead_properties),
-            ArchivedResource::CalendarScheduling(_)
-            | ArchivedResource::CalendarSchedulingCollection(_) => None,
+            ArchivedResource::CalendarEventNotification(_)
+            | ArchivedResource::CalendarEventNotificationCollection(_) => None,
         }
     }
 
@@ -393,11 +401,13 @@ impl<'x> ArchivedResource<'x> {
                 archive.inner.file.as_ref().map(|f| f.size.to_native())
             }
             ArchivedResource::CalendarEvent(archive) => archive.inner.size.to_native().into(),
-            ArchivedResource::CalendarScheduling(archive) => archive.inner.size.to_native().into(),
+            ArchivedResource::CalendarEventNotification(archive) => {
+                archive.inner.size.to_native().into()
+            }
             ArchivedResource::ContactCard(archive) => archive.inner.size.to_native().into(),
             ArchivedResource::AddressBook(_)
             | ArchivedResource::Calendar(_)
-            | ArchivedResource::CalendarSchedulingCollection(_) => None,
+            | ArchivedResource::CalendarEventNotificationCollection(_) => None,
         }
     }
 
@@ -408,27 +418,29 @@ impl<'x> ArchivedResource<'x> {
                 .file
                 .as_ref()
                 .and_then(|f| f.media_type.as_deref()),
-            ArchivedResource::CalendarEvent(_) | ArchivedResource::CalendarScheduling(_) => {
+            ArchivedResource::CalendarEvent(_) | ArchivedResource::CalendarEventNotification(_) => {
                 "text/calendar".into()
             }
             ArchivedResource::ContactCard(_) => "text/vcard".into(),
             ArchivedResource::AddressBook(_)
             | ArchivedResource::Calendar(_)
-            | ArchivedResource::CalendarSchedulingCollection(_) => None,
+            | ArchivedResource::CalendarEventNotificationCollection(_) => None,
         }
     }
 
-    pub fn display_name(&self, account_id: u32) -> Option<&str> {
+    pub fn display_name(&self, access_token: &AccessToken) -> Option<&str> {
         match self {
             ArchivedResource::Calendar(archive) => {
-                Some(archive.inner.preferences(account_id).name.as_str())
+                Some(archive.inner.preferences(access_token).name.as_str())
             }
             ArchivedResource::CalendarEvent(archive) => archive.inner.display_name.as_deref(),
-            ArchivedResource::AddressBook(archive) => archive.inner.display_name.as_deref(),
+            ArchivedResource::AddressBook(archive) => {
+                Some(archive.inner.preferences(access_token).name.as_str())
+            }
             ArchivedResource::ContactCard(archive) => archive.inner.display_name.as_deref(),
             ArchivedResource::FileNode(archive) => archive.inner.display_name.as_deref(),
-            ArchivedResource::CalendarScheduling(_)
-            | ArchivedResource::CalendarSchedulingCollection(_) => None,
+            ArchivedResource::CalendarEventNotification(_)
+            | ArchivedResource::CalendarEventNotificationCollection(_) => None,
         }
     }
 
@@ -459,7 +471,7 @@ impl<'x> ArchivedResource<'x> {
                 ReportSet::PrincipalMatch,
             ]
             .into(),
-            ArchivedResource::CalendarSchedulingCollection(_) => vec![
+            ArchivedResource::CalendarEventNotificationCollection(_) => vec![
                 ReportSet::SyncCollection,
                 ReportSet::CalendarQuery,
                 ReportSet::CalendarMultiGet,
@@ -480,10 +492,10 @@ impl<'x> ArchivedResource<'x> {
             ArchivedResource::FileNode(archive) if archive.inner.file.is_none() => {
                 vec![ResourceType::Collection].into()
             }
-            ArchivedResource::CalendarSchedulingCollection(true) => {
+            ArchivedResource::CalendarEventNotificationCollection(true) => {
                 vec![ResourceType::Collection, ResourceType::ScheduleInbox].into()
             }
-            ArchivedResource::CalendarSchedulingCollection(false) => {
+            ArchivedResource::CalendarEventNotificationCollection(false) => {
                 vec![ResourceType::Collection, ResourceType::ScheduleOutbox].into()
             }
             _ => None,
