@@ -19,7 +19,7 @@ use dav_proto::schema::{
     request::{DavPropertyValue, PropFind},
     response::{Href, MultiStatus, PropStat, Response},
 };
-use directory::{QueryParams, Type, backend::internal::manage::ManageDirectory};
+use directory::{PrincipalData, QueryParams, Type, backend::internal::manage::ManageDirectory};
 use groupware::RFC_3986;
 use groupware::cache::GroupwareCache;
 use hyper::StatusCode;
@@ -83,7 +83,9 @@ impl PrincipalPropFind for Server {
                 response.set_namespace(Namespace::CardDav);
                 false
             }
-            Collection::Calendar | Collection::CalendarEvent | Collection::CalendarScheduling => {
+            Collection::Calendar
+            | Collection::CalendarEvent
+            | Collection::CalendarEventNotification => {
                 response.set_namespace(Namespace::CalDav);
                 false
             }
@@ -122,11 +124,32 @@ impl PrincipalPropFind for Server {
                     .caused_by(trc::location!())?
                     .map(|p| {
                         let name = p.name;
-                        let description = p.description.unwrap_or_else(|| name.clone());
+                        let mut description = None;
+                        let mut emails = Vec::new();
+                        for data in p.data {
+                            match data {
+                                PrincipalData::Description(desc) => {
+                                    description = Some(desc);
+                                }
+                                PrincipalData::PrimaryEmail(email) => {
+                                    if emails.is_empty() {
+                                        emails.push(email);
+                                    } else {
+                                        emails.insert(0, email);
+                                    }
+                                }
+                                PrincipalData::EmailAlias(email) => {
+                                    emails.push(email);
+                                }
+                                _ => {}
+                            }
+                        }
+
+                        let description = description.unwrap_or_else(|| name.clone());
                         (
                             Cow::Owned(name.to_string()),
-                            description.to_string(),
-                            Cow::Owned(p.emails),
+                            description,
+                            Cow::Owned(emails),
                             p.typ,
                         )
                     })
