@@ -50,33 +50,27 @@ impl DirectoryStore for Store {
             && let Some(mut principal) = self.get_principal(account_id).await?
         {
             if let Some(secret) = secret
-                && !principal.verify_secret(secret, by.only_app_pass).await?
+                && !principal
+                    .verify_secret(secret, by.only_app_pass, true)
+                    .await?
             {
                 return Ok(None);
             }
 
             if by.return_member_of {
-                let mut roles = vec![];
-                let mut lists = vec![];
-                let mut member_of = vec![];
-
                 for member in self.get_member_of(principal.id).await? {
                     match member.typ {
-                        Type::List => lists.push(member.principal_id),
-                        Type::Role => roles.push(member.principal_id),
-                        _ => member_of.push(member.principal_id),
+                        Type::List => principal
+                            .data
+                            .push(PrincipalData::List(member.principal_id)),
+                        Type::Role => principal
+                            .data
+                            .push(PrincipalData::Role(member.principal_id)),
+                        _ => principal
+                            .data
+                            .push(PrincipalData::MemberOf(member.principal_id)),
                     }
                 }
-
-                if !roles.is_empty() {
-                    principal.data.push(PrincipalData::Roles(roles));
-                }
-                if !lists.is_empty() {
-                    principal.data.push(PrincipalData::Lists(lists));
-                }
-                if !member_of.is_empty() {
-                    principal.data.push(PrincipalData::MemberOf(member_of));
-                }
             }
             return Ok(Some(principal));
         }
@@ -165,25 +159,29 @@ impl DirectoryStore for Store {
     async fn expn_by_id(&self, list_id: u32) -> trc::Result<Vec<String>> {
         let mut results = Vec::new();
         for account_id in self.get_members(list_id).await? {
-            if let Some(email) = self
-                .get_principal(account_id)
-                .await?
-                .and_then(|p| p.emails.into_iter().next())
-            {
+            if let Some(email) = self.get_principal(account_id).await?.and_then(|p| {
+                p.data.into_iter().find_map(|data| {
+                    if let PrincipalData::PrimaryEmail(email) | PrincipalData::EmailAlias(email) =
+                        data
+                    {
+                        Some(email)
+                    } else {
+                        None
+                    }
+                })
+            }) {
                 results.push(email);
             }
         }
 
-        if let Some(emails) = self.get_principal(list_id).await?.and_then(|p| {
-            p.data.into_iter().find_map(|data| {
-                if let PrincipalData::ExternalMembers(members) = data {
-                    Some(members)
+        if let Some(principal) = self.get_principal(list_id).await? {
+            results.extend(principal.data.into_iter().filter_map(|data| {
+                if let PrincipalData::ExternalMember(member) = data {
+                    Some(member)
                 } else {
                     None
                 }
-            })
-        }) {
-            results.extend(emails);
+            }));
         }
 
         Ok(results)
