@@ -25,8 +25,7 @@ use serde::{Deserializer, Serializer};
 use serde_json::json;
 use smtp::{
     queue::{
-        self, ArchivedMessage, ArchivedStatus, DisplayArchivedResponse, ErrorDetails, QueueId,
-        Status, spool::SmtpSpool,
+        self, ArchivedMessage, ArchivedStatus, ErrorDetails, QueueId, Status, spool::SmtpSpool,
     },
     reporting::{dmarc::DmarcReporting, tls::TlsReporting},
 };
@@ -145,24 +144,24 @@ impl QueueManagement for Server {
 
         // Limit to tenant domains
         #[cfg(feature = "enterprise")]
-        if self.core.is_enterprise_edition() {
-            if let Some(tenant) = access_token.tenant {
-                tenant_domains = self
-                    .core
-                    .storage
-                    .data
-                    .list_principals(None, tenant.id.into(), &[Type::Domain], false, 0, 0)
-                    .await
-                    .map(|principals| {
-                        principals
-                            .items
-                            .into_iter()
-                            .map(|p| p.name)
-                            .collect::<Vec<_>>()
-                    })
-                    .caused_by(trc::location!())?
-                    .into();
-            }
+        if self.core.is_enterprise_edition()
+            && let Some(tenant) = access_token.tenant
+        {
+            tenant_domains = self
+                .core
+                .storage
+                .data
+                .list_principals(None, tenant.id.into(), &[Type::Domain], false, 0, 0)
+                .await
+                .map(|principals| {
+                    principals
+                        .items
+                        .into_iter()
+                        .map(|p| p.name)
+                        .collect::<Vec<_>>()
+                })
+                .caused_by(trc::location!())?
+                .into();
         }
 
         // SPDX-SnippetEnd
@@ -458,7 +457,12 @@ impl QueueManagement for Server {
                         {
                             let mut rua = Vec::new();
                             if let Some(report) = self
-                                .generate_tls_aggregate_report(&[event.clone()], &mut rua, None, 0)
+                                .generate_tls_aggregate_report(
+                                    std::slice::from_ref(&event),
+                                    &mut rua,
+                                    None,
+                                    0,
+                                )
                                 .await?
                             {
                                 result = Report::tls(event, report, rua).into();
