@@ -8,13 +8,13 @@ use compact_str::ToCompactString;
 
 use crate::{
     Command,
-    protocol::{ProtocolVersion, subscribe},
+    protocol::subscribe,
     receiver::{Request, bad},
     utf7::utf7_maybe_decode,
 };
 
 impl Request<Command> {
-    pub fn parse_subscribe(self, version: ProtocolVersion) -> trc::Result<subscribe::Arguments> {
+    pub fn parse_subscribe(self, is_utf8: bool) -> trc::Result<subscribe::Arguments> {
         match self.tokens.len() {
             1 => Ok(subscribe::Arguments {
                 mailbox_name: utf7_maybe_decode(
@@ -24,7 +24,7 @@ impl Request<Command> {
                         .unwrap()
                         .unwrap_string()
                         .map_err(|v| bad(self.tag.to_compact_string(), v))?,
-                    version,
+                    is_utf8,
                 ),
                 tag: self.tag,
             }),
@@ -36,10 +36,7 @@ impl Request<Command> {
 
 #[cfg(test)]
 mod tests {
-    use crate::{
-        protocol::{ProtocolVersion, subscribe},
-        receiver::Receiver,
-    };
+    use crate::{protocol::subscribe, receiver::Receiver};
 
     #[test]
     fn parse_subscribe() {
@@ -65,7 +62,7 @@ mod tests {
                 receiver
                     .parse(&mut command.as_bytes().iter())
                     .unwrap()
-                    .parse_subscribe(ProtocolVersion::Rev2)
+                    .parse_subscribe(true)
                     .unwrap(),
                 arguments
             );
