@@ -8,7 +8,7 @@ use super::get::VacationResponseGet;
 use crate::{JmapMethods, changes::state::StateManager};
 use common::{Server, auth::AccessToken, storage::index::ObjectIndexBuilder};
 use email::sieve::{
-    SieveScript, VacationResponse, activate::SieveScriptActivate, delete::SieveScriptDelete,
+    SieveScript, VacationResponse, delete::SieveScriptDelete, ingest::SieveScriptIngest,
 };
 use jmap_proto::{
     error::set::{SetError, SetErrorType},
@@ -24,12 +24,13 @@ use mail_parser::decoders::html::html_to_text;
 use std::borrow::Cow;
 use std::future::Future;
 use store::{
-    Serialize,
+    Serialize, SerializeInfallible,
     write::{Archiver, BatchBuilder},
 };
 use trc::AddContext;
 use types::{
     collection::{Collection, SyncCollection},
+    field::PrincipalField,
     id::Id,
 };
 
@@ -62,7 +63,6 @@ impl VacationResponseSet for Server {
             )
             .await?;
         let will_destroy = request.unwrap_destroy().into_valid().collect::<Vec<_>>();
-        let resource_token = self.get_resource_token(access_token, account_id).await?;
 
         // Process set or update requests
         let mut create_id = None;
@@ -127,10 +127,10 @@ impl VacationResponseSet for Server {
             .with_collection(Collection::SieveScript);
 
         // Process changes
+        let active_script_id = self.sieve_script_get_active_id(account_id).await?;
         if let Some(changes) = changes {
             // Obtain current script
             let document_id = self.get_vacation_sieve_script_id(account_id).await?;
-            let mut was_active = false;
 
             let (mut sieve, prev_sieve) = if let Some(document_id) = document_id {
                 let prev_sieve = self
@@ -143,7 +143,6 @@ impl VacationResponseSet for Server {
                     })?
                     .into_deserialized::<SieveScript>()
                     .caused_by(trc::location!())?;
-                was_active = prev_sieve.inner.is_active;
                 let mut sieve = prev_sieve.inner.clone();
                 if sieve.vacation_response.is_none() {
                     sieve.vacation_response = VacationResponse::default().into();
@@ -154,7 +153,6 @@ impl VacationResponseSet for Server {
                 (
                     SieveScript {
                         name: "vacation".into(),
-                        is_active: false,
                         blob_hash: Default::default(),
                         size: 0,
                         vacation_response: VacationResponse::default().into(),
@@ -255,12 +253,11 @@ impl VacationResponseSet for Server {
                     }
                 }
             }
-            sieve.is_active = is_active;
 
             let mut obj = ObjectIndexBuilder::new()
                 .with_current_opt(prev_sieve)
                 .with_changes(sieve)
-                .with_tenant_id(&resource_token);
+                .with_access_token(access_token);
 
             // Update id
             let document_id = if let Some(document_id) = document_id {
@@ -288,9 +285,25 @@ impl VacationResponseSet for Server {
                     .await?
                     .hash;
             };
+            batch.custom(obj).caused_by(trc::location!())?;
+
+            // Deactivate other sieve scripts
+            let was_active = active_script_id == Some(document_id);
+            if is_active {
+                if !was_active {
+                    batch
+                        .with_collection(Collection::Principal)
+                        .update_document(0)
+                        .set(PrincipalField::ActiveScriptId, document_id.serialize());
+                }
+            } else if was_active {
+                batch
+                    .with_collection(Collection::Principal)
+                    .update_document(0)
+                    .clear(PrincipalField::ActiveScriptId);
+            }
 
             // Write changes
-            batch.custom(obj).caused_by(trc::location!())?;
             if !batch.is_empty() {
                 response.new_state = Some(
                     self.commit_batch(batch)
@@ -301,16 +314,6 @@ impl VacationResponseSet for Server {
                 );
             }
 
-            // Deactivate other sieve scripts
-            if !was_active && is_active {
-                let (change_id, _) = self
-                    .sieve_activate_script(account_id, document_id.into())
-                    .await?;
-                if change_id > 0 {
-                    response.new_state = Some(change_id.into());
-                }
-            }
-
             // Add result
             if let Some(create_id) = create_id {
                 response.created.insert(
@@ -327,10 +330,17 @@ impl VacationResponseSet for Server {
                 if id.is_singleton()
                     && let Some(document_id) = self.get_vacation_sieve_script_id(account_id).await?
                 {
-                    self.sieve_script_delete(&resource_token, document_id, false, &mut batch)
+                    self.sieve_script_delete(account_id, document_id, access_token, &mut batch)
                         .await?;
+                    if active_script_id == Some(document_id) {
+                        batch
+                            .with_collection(Collection::Principal)
+                            .update_document(0)
+                            .clear(PrincipalField::ActiveScriptId);
+                    }
+
                     response.destroyed.push(id);
-                    continue;
+                    break;
                 }
 
                 response.not_destroyed.append(id, SetError::not_found());
