@@ -4,7 +4,6 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use super::Task;
 use common::Server;
 use email::message::bayes::EmailBayesTrain;
 use mail_parser::MessageParser;
@@ -15,14 +14,21 @@ use types::{blob_hash::BlobHash, collection::Collection};
 pub trait BayesTrainTask: Sync + Send {
     fn bayes_train(
         &self,
-        task: &Task,
+        account_id: u32,
+        document_id: u32,
         hash: &BlobHash,
         learn_spam: bool,
     ) -> impl Future<Output = bool> + Send;
 }
 
 impl BayesTrainTask for Server {
-    async fn bayes_train(&self, task: &Task, hash: &BlobHash, learn_spam: bool) -> bool {
+    async fn bayes_train(
+        &self,
+        account_id: u32,
+        document_id: u32,
+        hash: &BlobHash,
+        learn_spam: bool,
+    ) -> bool {
         let op_start = Instant::now();
         // Obtain raw message
         if let Ok(Some(raw_message)) = self
@@ -32,7 +38,7 @@ impl BayesTrainTask for Server {
         {
             // Train bayes classifier for account
             self.email_bayes_train(
-                task.account_id,
+                account_id,
                 0,
                 MessageParser::new().parse(&raw_message).unwrap_or_default(),
                 learn_spam,
@@ -41,9 +47,9 @@ impl BayesTrainTask for Server {
 
             trc::event!(
                 Spam(SpamEvent::TrainAccount),
-                AccountId = task.account_id,
+                AccountId = account_id,
                 Collection = Collection::Email,
-                DocumentId = task.document_id,
+                DocumentId = document_id,
                 Details = if learn_spam { "spam" } else { "ham" },
                 Elapsed = op_start.elapsed(),
             );
@@ -51,8 +57,8 @@ impl BayesTrainTask for Server {
         } else {
             trc::event!(
                 TaskQueue(TaskQueueEvent::BlobNotFound),
-                AccountId = task.account_id,
-                DocumentId = task.document_id,
+                AccountId = account_id,
+                DocumentId = document_id,
                 BlobId = hash.as_slice(),
             );
             false
