@@ -4,7 +4,6 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use super::Task;
 use common::Server;
 use directory::{Type, backend::internal::manage::ManageDirectory};
 use email::message::{index::IndexMessageText, metadata::MessageMetadata};
@@ -24,7 +23,12 @@ use types::{
 };
 
 pub trait FtsIndexTask: Sync + Send {
-    fn fts_index(&self, task: &Task, hash: &BlobHash) -> impl Future<Output = bool> + Send;
+    fn fts_index(
+        &self,
+        account_id: u32,
+        document_id: u32,
+        hash: &BlobHash,
+    ) -> impl Future<Output = bool> + Send;
     fn fts_reindex(
         &self,
         account_id: Option<u32>,
@@ -33,7 +37,7 @@ pub trait FtsIndexTask: Sync + Send {
 }
 
 impl FtsIndexTask for Server {
-    async fn fts_index(&self, task: &Task, hash: &BlobHash) -> bool {
+    async fn fts_index(&self, account_id: u32, document_id: u32, hash: &BlobHash) -> bool {
         // Obtain raw message
         let op_start = Instant::now();
         let raw_message = if let Ok(Some(raw_message)) = self
@@ -45,8 +49,8 @@ impl FtsIndexTask for Server {
         } else {
             trc::event!(
                 TaskQueue(TaskQueueEvent::BlobNotFound),
-                AccountId = task.account_id,
-                DocumentId = task.document_id,
+                AccountId = account_id,
+                DocumentId = document_id,
                 BlobId = hash.as_slice(),
             );
             return false;
@@ -54,9 +58,9 @@ impl FtsIndexTask for Server {
 
         match self
             .get_archive_by_property(
-                task.account_id,
+                account_id,
                 Collection::Email,
-                task.document_id,
+                document_id,
                 EmailField::Metadata.into(),
             )
             .await
@@ -67,14 +71,14 @@ impl FtsIndexTask for Server {
                         // Index message
                         let document =
                             FtsDocument::with_default_language(self.core.jmap.default_language)
-                                .with_account_id(task.account_id)
+                                .with_account_id(account_id)
                                 .with_collection(Collection::Email)
-                                .with_document_id(task.document_id)
+                                .with_document_id(document_id)
                                 .index_message(metadata, &raw_message);
                         if let Err(err) = self.core.storage.fts.index(document).await {
                             trc::error!(
-                                err.account_id(task.account_id)
-                                    .document_id(task.document_id)
+                                err.account_id(account_id)
+                                    .document_id(document_id)
                                     .details("Failed to index email in FTS index")
                             );
 
@@ -83,16 +87,16 @@ impl FtsIndexTask for Server {
 
                         trc::event!(
                             MessageIngest(MessageIngestEvent::FtsIndex),
-                            AccountId = task.account_id,
+                            AccountId = account_id,
                             Collection = Collection::Email,
-                            DocumentId = task.document_id,
+                            DocumentId = document_id,
                             Elapsed = op_start.elapsed(),
                         );
                     }
                     Err(err) => {
                         trc::error!(
-                            err.account_id(task.account_id)
-                                .document_id(task.document_id)
+                            err.account_id(account_id)
+                                .document_id(document_id)
                                 .details("Failed to unarchive email metadata")
                         );
                     }
@@ -102,8 +106,8 @@ impl FtsIndexTask for Server {
                         trc::event!(
                             TaskQueue(TaskQueueEvent::MetadataNotFound),
                             Details = "E-mail blob hash mismatch",
-                            AccountId = task.account_id,
-                            DocumentId = task.document_id,
+                            AccountId = account_id,
+                            DocumentId = document_id,
                         );
                     }
                 }
@@ -112,8 +116,8 @@ impl FtsIndexTask for Server {
             }
             Err(err) => {
                 trc::error!(
-                    err.account_id(task.account_id)
-                        .document_id(task.document_id)
+                    err.account_id(account_id)
+                        .document_id(document_id)
                         .caused_by(trc::location!())
                         .details("Failed to retrieve email metadata")
                 );
@@ -125,8 +129,8 @@ impl FtsIndexTask for Server {
                 trc::event!(
                     TaskQueue(TaskQueueEvent::MetadataNotFound),
                     Details = "E-mail metadata not found",
-                    AccountId = task.account_id,
-                    DocumentId = task.document_id,
+                    AccountId = account_id,
+                    DocumentId = document_id,
                 );
                 true
             }
