@@ -926,7 +926,7 @@ impl QueuedMessage {
                         .and_then(|ip| ip.host.as_deref())
                         .or(conn_strategy.ehlo_hostname.as_deref())
                         .unwrap_or(server.core.network.server_name.as_str());
-                    let params = SessionParams {
+                    let mut params = SessionParams {
                         session_id: message.span_id,
                         server: &server,
                         credentials: remote_host.credentials(),
@@ -934,6 +934,7 @@ impl QueuedMessage {
                         hostname: envelope.mx,
                         local_hostname,
                         conn_strategy,
+                        capabilities: None,
                     };
 
                     // Prepare TLS connector
@@ -1029,36 +1030,36 @@ impl QueuedMessage {
                                     );
 
                                     // Verify DANE
-                                    if let Some(dane_policy) = &dane_policy {
-                                        if let Err(status) = dane_policy.verify(
+                                    if let Some(dane_policy) = &dane_policy
+                                        && let Err(status) = dane_policy.verify(
                                             message.span_id,
                                             envelope.mx,
                                             smtp_client.tls_connection().peer_certificates(),
-                                        ) {
-                                            // Report DANE verification failure
-                                            if let Some(tls_report) = &tls_report {
-                                                server
-                                                    .schedule_report(TlsEvent {
-                                                        policy: dane_policy.into(),
-                                                        domain: domain.to_string(),
-                                                        failure: FailureDetails::new(
-                                                            ResultType::ValidationFailure,
-                                                        )
-                                                        .with_receiving_mx_hostname(envelope.mx)
-                                                        .with_receiving_ip(remote_ip)
-                                                        .with_failure_reason_code(
-                                                            "No matching certificates found.",
-                                                        )
-                                                        .into(),
-                                                        tls_record: tls_report.record.clone(),
-                                                        interval: tls_report.interval,
-                                                    })
-                                                    .await;
-                                            }
-
-                                            last_status = status;
-                                            continue 'next_host;
+                                        )
+                                    {
+                                        // Report DANE verification failure
+                                        if let Some(tls_report) = &tls_report {
+                                            server
+                                                .schedule_report(TlsEvent {
+                                                    policy: dane_policy.into(),
+                                                    domain: domain.to_string(),
+                                                    failure: FailureDetails::new(
+                                                        ResultType::ValidationFailure,
+                                                    )
+                                                    .with_receiving_mx_hostname(envelope.mx)
+                                                    .with_receiving_ip(remote_ip)
+                                                    .with_failure_reason_code(
+                                                        "No matching certificates found.",
+                                                    )
+                                                    .into(),
+                                                    tls_record: tls_report.record.clone(),
+                                                    interval: tls_report.interval,
+                                                })
+                                                .await;
                                         }
+
+                                        last_status = status;
+                                        continue 'next_host;
                                     }
 
                                     // Report TLS success
@@ -1132,6 +1133,7 @@ impl QueuedMessage {
                                         continue 'next_host;
                                     } else {
                                         // TLS is not required, proceed in plain-text
+                                        params.capabilities = Some(capabilities);
                                         message
                                             .deliver(
                                                 smtp_client,
