@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
@@ -178,7 +178,7 @@ impl Collector {
             EventType::Queue(QueueEvent::QueueAutogenerated | QueueEvent::QueueDsn) => {
                 QUEUE_COUNT.increment();
             }
-            EventType::TaskQueue(TaskQueueEvent::Index) => {
+            EventType::MessageIngest(MessageIngestEvent::FtsIndex) => {
                 MESSAGE_INDEX_TIME.observe(elapsed);
             }
             EventType::Store(StoreEvent::BlobWrite) => {
@@ -592,9 +592,7 @@ impl EventType {
             ) => true,
             EventType::Housekeeper(_) => false,
             EventType::TaskQueue(
-                TaskQueueEvent::Index
-                | TaskQueueEvent::BlobNotFound
-                | TaskQueueEvent::MetadataNotFound,
+                TaskQueueEvent::BlobNotFound | TaskQueueEvent::MetadataNotFound,
             ) => true,
             EventType::Milter(
                 MilterEvent::ActionAccept
@@ -673,6 +671,13 @@ impl EventType {
                 | TelemetryEvent::PrometheusExporterError
                 | TelemetryEvent::JournalError,
             ) => true,
+            EventType::Calendar(
+                CalendarEvent::AlarmSent
+                | CalendarEvent::AlarmFailed
+                | CalendarEvent::ItipMessageReceived
+                | CalendarEvent::ItipMessageSent
+                | CalendarEvent::ItipMessageError,
+            ) => true,
             _ => false,
         }
     }
