@@ -47,7 +47,7 @@ async fn internal_directory() {
                 TestPrincipal {
                     name: "john".into(),
                     description: Some("John Doe".into()),
-                    secrets: vec!["secret".into(), "secret2".into()],
+                    secrets: vec!["secret".into(), "$app$secret2".into()],
                     ..Default::default()
                 }
                 .into(),
@@ -148,7 +148,7 @@ async fn internal_directory() {
                 TestPrincipal {
                     name: "jane".into(),
                     description: Some("Jane Doe".into()),
-                    secrets: vec!["my_secret".into(), "my_secret2".into()],
+                    secrets: vec!["my_secret".into(), "$app$my_secret2".into()],
                     emails: vec!["jane@example.org".into()],
                     quota: 123,
                     ..Default::default()
@@ -188,7 +188,7 @@ async fn internal_directory() {
                 name: "jane".into(),
                 description: Some("Jane Doe".into()),
                 emails: vec!["jane@example.org".into()],
-                secrets: vec!["my_secret".into(), "my_secret2".into()],
+                secrets: vec!["my_secret".into(), "$app$my_secret2".into()],
                 quota: 123,
                 ..Default::default()
             })
@@ -366,7 +366,7 @@ async fn internal_directory() {
                 id: john_id,
                 name: "john".into(),
                 description: Some("John Doe".into()),
-                secrets: vec!["secret".into(), "secret2".into()],
+                secrets: vec!["secret".into(), "$app$secret2".into()],
                 emails: vec!["john@example.org".into()],
                 member_of: vec!["sales".into(), "support".into()],
                 lists: vec!["list".into()],
@@ -411,7 +411,7 @@ async fn internal_directory() {
                 id: john_id,
                 name: "john".into(),
                 description: Some("John Doe".into()),
-                secrets: vec!["secret".into(), "secret2".into()],
+                secrets: vec!["secret".into(), "$app$secret2".into()],
                 emails: vec!["john@example.org".into()],
                 member_of: vec!["sales".into()],
                 lists: vec!["list".into()],
@@ -777,6 +777,11 @@ pub trait TestInternalDirectory {
     async fn create_test_list(&self, login: &str, name: &str, emails: &[&str]) -> u32;
     async fn set_test_quota(&self, login: &str, quota: u32);
     async fn add_permissions(&self, login: &str, permissions: impl IntoIterator<Item = Permission>);
+    async fn remove_permissions(
+        &self,
+        login: &str,
+        permissions: impl IntoIterator<Item = Permission>,
+    );
     async fn add_to_group(&self, login: &str, group: &str) -> ChangedPrincipals;
     async fn remove_from_group(&self, login: &str, group: &str) -> ChangedPrincipals;
     async fn remove_test_alias(&self, login: &str, alias: &str);
@@ -815,6 +820,10 @@ impl TestInternalDirectory for Store {
                     PrincipalField::Roles,
                     PrincipalValue::String(role.into()),
                 ),
+                PrincipalUpdate::add_item(
+                    PrincipalField::EnabledPermissions,
+                    PrincipalValue::String(Permission::UnlimitedRequests.name().into()),
+                ),
             ]))
             .await
             .unwrap();
@@ -835,6 +844,12 @@ impl TestInternalDirectory for Store {
                     .with_field(
                         PrincipalField::Roles,
                         PrincipalValue::StringList(vec![role.into()]),
+                    )
+                    .with_field(
+                        PrincipalField::EnabledPermissions,
+                        PrincipalValue::StringList(vec![
+                            Permission::UnlimitedRequests.name().into(),
+                        ]),
                     ),
                 None,
                 None,
@@ -935,6 +950,28 @@ impl TestInternalDirectory for Store {
         .unwrap();
     }
 
+    async fn remove_permissions(
+        &self,
+        login: &str,
+        permissions: impl IntoIterator<Item = Permission>,
+    ) {
+        self.update_principal(
+            UpdatePrincipal::by_name(login).with_updates(
+                permissions
+                    .into_iter()
+                    .map(|p| {
+                        PrincipalUpdate::remove_item(
+                            PrincipalField::EnabledPermissions,
+                            PrincipalValue::String(p.name().to_string()),
+                        )
+                    })
+                    .collect(),
+            ),
+        )
+        .await
+        .unwrap();
+    }
+
     async fn add_to_group(&self, login: &str, group: &str) -> ChangedPrincipals {
         self.update_principal(UpdatePrincipal::by_name(login).with_updates(vec![
             PrincipalUpdate::add_item(
