@@ -276,7 +276,7 @@ impl WebDavTest {
     }
 
     pub async fn assert_is_empty(&self) {
-        assert_is_empty(self.server.clone()).await;
+        assert_is_empty(&self.server).await;
         self.clear_cache();
     }
 }
@@ -562,6 +562,15 @@ impl DavResponse {
         }
     }
 
+    pub fn expect_body(&self) -> &str {
+        if self.body.is_ok() {
+            self.body.as_ref().unwrap()
+        } else {
+            self.dump_response();
+            panic!("Expected body but no body was returned.")
+        }
+    }
+
     pub fn header(&self, header: &str) -> &str {
         if let Some(value) = self.headers.get(header) {
             value
@@ -1199,6 +1208,9 @@ auto-add = true
 [dav.collection]
 assisted-discovery = {ASSISTED_DISCOVERY}
 
+[sharing]
+allow-directory-query = true
+
 [store."auth"]
 type = "sqlite"
 path = "{TMP}/auth.db"
